.. :changelog:

History
-------

0.0.1 (2018-01-09)
++++++++++++++++++

* First release on PyPI.

0.0.2 (2018-01-16)
++++++++++++++++++

* Improved testing and stability


0.0.6 (2018-01-29)
++++++++++++++++++

* Added feature to align coordinate system of different images

0.1.0 (2018-02-25)
++++++++++++++++++

* Major design update

0.1.1 (2018-03-05)
++++++++++++++++++

* minor update to facilitate options without lensing

0.1.2 (2018-03-10)
++++++++++++++++++

* ellipticity parameter handling changed
* time-delay distance sampling included
* parameter handling for sampling more flexible
* removed redundancies in the light and mass profiles